@@ -1,3 +1,3 @@
-from .param_type import ParamType
+from .params import ParamType
 from .parser import extract_command_name
 from .parser import parse_argv
