@@ -1,10 +1,26 @@
-import typing as t
+"""
+TODO:
+    currently, the following options are defined but not used:
+        ALIGN_ARGS_AND_OPTS_FIELD_WIDTH
+        FALLBACK_TO_HELP_IF_ARGPARSE_FAILED
+        FALLBACK_TYPE
+        PRETTY_ERROR
+        USE_RICH_MARKUP
+"""
 
-# -----------------------------------------------------------------------------
-# rich style
 
-# PRETTY_ERROR = True
-TITLE_HEAD_STYLE: t.Literal['system_dependent', 'fixed'] = 'system_dependent'
+class T:
+    from typing import Literal
+    ArgNameStyle = Literal['AAA_BBB', 'AAA-BBB', 'aaa_bbb', 'aaa-bbb', 'AaaBbb']
+    FallbackType = Literal['any', 'str']
+    TitleHeadStyle = Literal['system_dependent', 'fixed']
+
+
+# appearance style
+ALIGN_ARGS_AND_OPTS_FIELD_WIDTH = False
+ARG_NAME_STYLE: T.ArgNameStyle = 'AAA_BBB'
+PRETTY_ERROR = True
+TITLE_HEAD_STYLE: T.TitleHeadStyle = 'system_dependent'
 ''' the difference:
         system      system_dependent    fixed
         ------      ----------------    -----
@@ -16,7 +32,9 @@ TITLE_HEAD_STYLE: t.Literal['system_dependent', 'fixed'] = 'system_dependent'
 '''
 USE_RICH_MARKUP = True
 
-FALLBACK_TYPE: t.Literal['any', 'str'] = 'any'  # see [./parser/func_parser.py]
+# fallback
+FALLBACK_TYPE: T.FallbackType = 'any'
+#   see [./parser/func_parser.py : def parse_function()]
 FALLBACK_DESC = '[dim]no description[/]'
 ''' suggested:
         <empty string>
@@ -25,14 +43,14 @@ FALLBACK_DESC = '[dim]no description[/]'
     see also: [./cli.py : def show2() : def show()]
 '''
 FALLBACK_TO_HELP_IF_ARGPARSE_FAILED = False
-#   see [./argparse/argv2.py : def report]
-
-ALIGN_ARGS_AND_OPTS_FIELD_WIDTH = False
+#   see [./argparse/argv.py : class ArgvVendor : def report()]
 
+# console related
 WARNING_IF_RUNNING_ON_PYCHARM_CONSOLE = False
 CONSOLE_WIDTH = None
 
 
+# dynamic settings
 class Dynamic:
     PREFERRED_FIELD_WIDTH_OF_NAME = 0
     PREFERRED_FIELD_WIDTH_OF_TYPE = len('NUMBER')
@@ -43,6 +61,3 @@ def apply_changes():
         from .console import console
         if console.width > CONSOLE_WIDTH:
             console.width = CONSOLE_WIDTH
-    if FALLBACK_TYPE == 'str':
-        # TODO: see [./parser/func_parser.py : def parse_function].
-        pass
